@@ -10,4 +10,9 @@ $( document ).ready(function() {
         $lbl.attr("class", "checkmark")
         $(this).after($lbl);
     });
+
+    $(".ddm-message").each(function() {
+      $(this).animate({opacity: 1, top: 0}, 300);
+      setTimeout(() => {  $(this).animate({opacity: 0, top: -50}, 300); }, 7000);
+    })
 });
